<template>
  <div class="m3u8-player-container">
    <div v-if="!supported" class="error-message">
      您的浏览器不支持 HLS 直播播放
    </div>
    <div v-else class="video-player">
      <video
        ref="videoElement"
        autoplay
        :muted="true"
        class="video-js"
      ></video>
      <div v-if="error" class="error-message">
        <span>{{ error }}</span>
      </div>
      <div v-if="loading" class="loading-message">正在加载直播流...</div>
      <div class="controls">
        <el-tooltip :content="isPlaying ? '暂停' : '播放'" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="togglePlay">
            <i :class="isPlaying ? 'el-icon-video-pause' : 'el-icon-video-play'"></i>
          </el-button>
        </el-tooltip>

        <div class="volume-control" @mouseenter="volumeSliderVisible = true" @mouseleave="volumeSliderVisible = false">
            <el-button class="control-btn" circle @click="toggleMute">
              <svg-icon :name="volumeIcon" class="info-icon" />
            </el-button>
          <div class="volume-slider-container" v-show="volumeSliderVisible">
            <el-slider
              v-model="volume"
              :min="0"
              :max="100"
              :step="1"
              vertical
              height="80px"
              @input="handleVolumeChange"
            ></el-slider>
          </div>
        </div>

        <el-tooltip content="设备信息" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="showDeviceInfo">
            <i class="el-icon-info"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip content="云台操作" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="togglePtz">
            <i class="el-icon-help"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip content="旋转画面" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="rotateVideo">
            <i class="el-icon-refresh"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip content="截图" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="takeSnapshot">
            <i class="el-icon-camera"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip :content="isRecording ? '结束录制' : '开始录制'" placement="top" :open-delay="500">
          <el-button 
            class="control-btn" 
            circle 
            @click="toggleRecording"
            :type="isRecording ? 'primary' : ''"
          >
            <i class="el-icon-video-camera"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip :content="isTalking ? '结束喊话' : '喊话'" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="startTalk" :type="isTalking ? 'primary' : ''">
            <i class="el-icon-microphone"></i>
          </el-button>
        </el-tooltip>

        <el-tooltip content="全屏" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="fullscreen">
            <i class="el-icon-full-screen"></i>
          </el-button>
        </el-tooltip>
      </div>
      <div class="record-controls">
        <div class="record-status" v-if="isRecording">
          <span class="record-indicator"></span>
          正在录制... {{ formatRecordingTime }}
        </div>
      </div>
      
      <!-- 设备信息对话框 -->
      <el-dialog
        title="设备信息"
        :visible.sync="deviceInfoVisible"
        width="300px"
        :modal="false" 
        :append-to-body=true
        custom-class="device-info-dialog"
      >
        <div class="device-info">
          <p><strong>设备ID：</strong>{{ deviceInfo.deviceId || '-' }}</p>
          <p><strong>设备名称：</strong>{{ deviceInfo.deviceName || '-' }}</p>
          <p><strong>设备类型：</strong>{{ deviceInfo.deviceType || '-' }}</p>
          <p><strong>在线状态：</strong>{{ deviceInfo.online ? '在线' : '离线' }}</p>
          <p><strong>分辨率：</strong>{{ deviceInfo.resolution || '-' }}</p>
          <p><strong>码率：</strong>{{ deviceInfo.bitrate || '-' }}</p>
        </div>
      </el-dialog>
    </div>
  </div>
</template>

<script>
import Hls from 'hls.js'
import { getDeviceInfo } from '@/api/video-controller.js'

export default {
  name: 'M3U8Player',
  props: {
    url: {
      type: String,
      required: true
    },
    deviceId: {
      type: String,
      default: ''
    },
    deviceName: {
      type: String,
      default: ''
    },
    deviceType: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      hlsPlayer: null,
      isPlaying: true,
      isMuted: true,
      volume: 50,
      preMuteVolume: 50,
      loading: false,
      error: null,
      supported: Hls.isSupported(),
      rotationDegree: 0,
      isTalking: false,
      deviceInfoVisible: false,
      deviceInfo: {
        deviceId: '',
        deviceName: '',
        deviceType: '',
        online: false,
        resolution: '',
        bitrate: ''
      },
      isRecording: false,
      mediaRecorder: null,
      recordedChunks: [],
      recordingStartTime: null,
      recordingDuration: 0,
      recordingTimer: null,
      resizeTimer: null,
      frameTimer: null,
      volumeSliderVisible: false
    }
  },
  watch: {
    url() {
      this.destroyPlayer()
      this.initPlayer()
    },
    volume(newVal) {
      if (newVal > 0 && this.preMuteVolume === 0) {
        this.preMuteVolume = newVal
      }
    }
  },
  computed: {
    formatRecordingTime() {
      const minutes = Math.floor(this.recordingDuration / 60);
      const seconds = this.recordingDuration % 60;
      return `${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`;
    },
    volumeIcon() {
      if (this.isMuted) {
        return 'volumeDisable';
      } else if (this.volume > 50) {
        return 'volumeHigh';
      } else if (this.volume > 0) {
        return 'volumeMiddle';
      } else {
        return 'volumeLow';
      }
    },
  },
  mounted() {
    if (this.supported) {
      this.initPlayer();
    }
    
    const videoElement = this.$refs.videoElement;
    if (videoElement) {
      videoElement.addEventListener('loadedmetadata', this.handleVideoMetadata);
    }

    window.addEventListener('resize', this.handleResize);

    this.deviceInfo.deviceId = this.deviceId;
    this.deviceInfo.deviceName = this.deviceName;
    this.deviceInfo.deviceType = this.deviceType;

    if (videoElement?.parentElement) {
      videoElement.parentElement.classList.add('rotate-0');
    }
  },
  beforeDestroy() {
    this.destroyPlayer();

    const videoElement = this.$refs.videoElement;
    if (videoElement) {
      videoElement.removeEventListener('loadedmetadata', this.handleVideoMetadata);
    }
    window.removeEventListener('resize', this.handleResize);

    if (this.isTalking) {
      this.stopTalk();
    }

    if (this.rotationDegree !== 0 && videoElement) {
      videoElement.style.transform = '';
      videoElement.style.maxWidth = '';
      videoElement.style.maxHeight = '';
    }

    this.clearRecordingTimer();
    if (this.resizeTimer) {
      clearTimeout(this.resizeTimer);
      this.resizeTimer = null;
    }
    if (this.frameTimer) {
      clearInterval(this.frameTimer);
      this.frameTimer = null;
    }

    if (this.mediaRecorder && this.mediaRecorder.state !== 'inactive') {
      this.mediaRecorder.stop();
    }
    this.recordedChunks = [];
  },
  methods: {
    refresh() {
      this.$emit('refresh', this.deviceId);
    },
    initPlayer() {
      if (!this.url) {
        this.error = '播放地址不能为空'
        return
      }

      if (this.hlsPlayer) {
        this.destroyPlayer()
      }

      this.loading = true
      this.error = null

      const videoElement = this.$refs.videoElement
      if (!videoElement) return

      if (Hls.isSupported()) {
        this.hlsPlayer = new Hls({
          debug: false,
          enableWorker: true,
          lowLatencyMode: true,
          backBufferLength: 90
        });

        this.hlsPlayer.attachMedia(videoElement);
        this.hlsPlayer.on(Hls.Events.MEDIA_ATTACHED, () => {
          this.hlsPlayer.loadSource(this.url);
        });

        this.hlsPlayer.on(Hls.Events.ERROR, (event, data) => {
          if (data.fatal) {
            switch (data.type) {
              case Hls.ErrorTypes.NETWORK_ERROR:
                this.error = '网络错误';
                break;
              case Hls.ErrorTypes.MEDIA_ERROR:
                this.error = '媒体错误';
                break;
              default:
                this.error = '播放错误';
                break;
            }
            console.error('HLS播放错误:', data);
            this.loading = false;
          }
        });

        this.hlsPlayer.on(Hls.Events.MANIFEST_PARSED, () => {
          this.loading = false;
          this.isPlaying = true;
          
          // 确保视频是静音的，以便自动播放
          videoElement.muted = true;
          this.isMuted = true;
          
          // 尝试播放视频
          const playPromise = videoElement.play();
          
          if (playPromise !== undefined) {
            playPromise.then(() => {
              console.log('自动播放成功');
              this.isMuted = false;
            }).catch(err => {
              console.error('自动播放失败:', err);
              // 如果自动播放失败，添加点击事件监听器
              this.addPlayEventListener(videoElement);
            });
          }
        });

      } else if (videoElement.canPlayType('application/vnd.apple.mpegurl')) {
        // 对于原生支持HLS的浏览器（如Safari）
        videoElement.src = this.url;
        videoElement.addEventListener('loadedmetadata', () => {
          this.loading = false;
          this.isPlaying = true;
          videoElement.play().catch(err => {
            console.error('自动播放失败:', err);
          });
        });
        videoElement.addEventListener('error', () => {
          this.error = '播放错误';
          this.loading = false;
        });
      } else {
        this.error = '您的浏览器不支持HLS播放';
        this.loading = false;
      }
    },
    destroyPlayer() {
      if (this.hlsPlayer) {
        this.hlsPlayer.destroy();
        this.hlsPlayer = null;
      }
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        videoElement.src = '';
      }
      this.isPlaying = false;
    },
    togglePlay() {
      const videoElement = this.$refs.videoElement;
      if (!videoElement) return;

      if (this.isPlaying) {
        videoElement.pause();
        // this.hlsPlayer.destroy();
      } else {
        this.initPlayer();
      }
      this.isPlaying = !this.isPlaying;
    },
    toggleMute() {
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        videoElement.muted = !videoElement.muted;
        this.isMuted = videoElement.muted;
        if (this.volume > 0) {
          this.preMuteVolume = this.volume;
          this.volume = 0;
        } else {
          this.volume = this.preMuteVolume;
        }
        if (!this.isMuted) {
          videoElement.volume = this.volume / 100;
        } else {
          this.volume = 0;
          videoElement.volume = 0;
        }
      }
    },
    handleVolumeChange(value) {
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        videoElement.volume = value / 100;
        if (value === 0) {
          videoElement.muted = true;
          this.isMuted = true;
        } else if (this.isMuted) {
          videoElement.muted = false;
          this.isMuted = false;
        }
      }
    },
    togglePtz() {
      this.$emit('toggleControlPanel');
    },
    fullscreen() {
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        if (videoElement.requestFullscreen) {
          videoElement.requestFullscreen();
        } else if (videoElement.webkitRequestFullscreen) {
          videoElement.webkitRequestFullscreen();
        } else if (videoElement.msRequestFullscreen) {
          videoElement.msRequestFullscreen();
        }
      }
    },
    toggleRecording() {
      if (this.isRecording) {
        this.stopRecording();
        clearInterval(this.recordingTimer);
        this.recordingTimer = null;
      } else {
        this.startRecording();
        this.recordingStartTime = new Date();
        this.recordingDuration = 0;
        this.recordingTimer = setInterval(() => {
          this.recordingDuration = Math.floor((new Date() - this.recordingStartTime) / 1000);
        }, 1000);
      }
    },
    startRecording() {
      const videoElement = this.$refs.videoElement;
      if (!videoElement || !videoElement.videoWidth) {
        this.$message.error('无法获取视频元素，请确保视频正在播放');
        return;
      }

      try {
        const canvas = document.createElement('canvas');
        canvas.width = videoElement.videoWidth;
        canvas.height = videoElement.videoHeight;
        const ctx = canvas.getContext('2d');
        const stream = canvas.captureStream(30);

        let options;
        if (MediaRecorder.isTypeSupported('video/webm;codecs=h264')) {
          options = {
            mimeType: 'video/webm;codecs=h264',
            videoBitsPerSecond: 2500000
          };
        } else if (MediaRecorder.isTypeSupported('video/webm;codecs=vp9')) {
          options = {
            mimeType: 'video/webm;codecs=vp9',
            videoBitsPerSecond: 2500000
          };
        } else {
          options = {
            mimeType: 'video/webm;codecs=vp8',
            videoBitsPerSecond: 2500000
          };
        }

        this.mediaRecorder = new MediaRecorder(stream, options);
        this.recordedChunks = [];

        this.mediaRecorder.ondataavailable = (event) => {
          if (event.data && event.data.size > 0) {
            this.recordedChunks.push(event.data);
          }
        };

        this.mediaRecorder.onstop = async () => {
          try {
            await new Promise(resolve => setTimeout(resolve, 100));
            
            const metadata = {
              codec: this.mediaRecorder.mimeType,
              duration: (Date.now() - this.recordStartTime) / 1000,
              width: canvas.width,
              height: canvas.height,
              framerate: 30
            };
            
            const metadataChunk = new Blob([JSON.stringify(metadata)], { type: 'application/json' });
            const videoBlob = new Blob(this.recordedChunks, { type: this.mediaRecorder.mimeType });
            const finalBlob = new Blob([metadataChunk, videoBlob], { type: this.mediaRecorder.mimeType });
            
            const reader = new FileReader();
            
            reader.onload = () => {
              const url = URL.createObjectURL(finalBlob);
              const a = document.createElement('a');
              document.body.appendChild(a);
              a.style.display = 'none';
              a.href = url;
              
              const timestamp = new Date().toISOString().replace(/[:.]/g, '-');
              a.download = `record_${this.deviceId}_${timestamp}.webm`;
              
              a.click();
              
              setTimeout(() => {
                URL.revokeObjectURL(url);
                document.body.removeChild(a);
                
                this.isRecording = false;
                this.recordStartTime = null;
                this.recordedChunks = [];
                
                this.$message({
                  message: '录像已保存到您的下载文件夹',
                  type: 'success',
                  duration: 3000
                });
              }, 100);
            };
            
            reader.onerror = () => {
              throw new Error('文件保存失败');
            };
            
            reader.readAsArrayBuffer(finalBlob);
            
          } catch (error) {
            console.error('保存录像失败:', error);
            this.$message.error(`保存录像失败: ${error.message || '未知错误'}`);
            
            this.isRecording = false;
            this.recordStartTime = null;
            this.recordedChunks = [];
          }
        };

        this.frameTimer = setInterval(() => {
          if (videoElement.readyState === videoElement.HAVE_ENOUGH_DATA) {
            ctx.drawImage(videoElement, 0, 0, canvas.width, canvas.height);
          }
        }, 1000 / 30);

        this.mediaRecorder.start(1000);
        this.isRecording = true;
        this.recordStartTime = Date.now();
        
        this.$message({
          message: '开始录像',
          type: 'success',
          duration: 2000
        });
        
      } catch (error) {
        console.error('开始录像失败:', error);
        this.$message.error(`开始录像失败: ${error.message || '未知错误'}`);
      }
    },
    stopRecording() {
      if (!this.mediaRecorder || this.mediaRecorder.state === 'inactive') {
        this.$message.error('没有正在进行的录像');
        return;
      }
      
      try {
        this.mediaRecorder.stop();
        
        if (this.recordingTimer) {
          clearInterval(this.recordingTimer);
          this.recordingTimer = null;
        }
        
        if (this.frameTimer) {
          clearInterval(this.frameTimer);
          this.frameTimer = null;
        }
        
      } catch (error) {
        console.error('停止录像失败:', error);
        this.$message.error(`停止录像失败: ${error.message || '未知错误'}`);
        
        this.isRecording = false;
        this.recordStartTime = null;
      }
    },
    showDeviceInfo() {
      this.updateDeviceInfo();
      this.deviceInfoVisible = true;
    },
    updateDeviceInfo() {
      const videoElement = this.$refs.videoElement;
      if (videoElement && this.hlsPlayer) {
        getDeviceInfo(this.deviceId).then((res) => {
          this.deviceInfo = {
            ...res,
            deviceId: res.device_id,
            deviceName: res.device_name,
            deviceType: res.device_type,
            online: res.device_state === "ONLINE" ? true : false,
            resolution: videoElement.videoWidth ? `${videoElement.videoWidth}x${videoElement.videoHeight}` : '-',
            bitrate: this.hlsPlayer.stats ? `${Math.round(this.hlsPlayer.stats.bitrate / 1024)} kbps` : '-'
          };
        });
      }
    },
    takeSnapshot() {
      const videoElement = this.$refs.videoElement;
      if (!videoElement || !videoElement.videoWidth) {
        this.$message.error('视频未就绪，无法截图');
        return;
      }

      try {
        const canvas = document.createElement('canvas');
        const ctx = canvas.getContext('2d');
        
        if (this.rotationDegree === 90 || this.rotationDegree === 270) {
          canvas.width = videoElement.videoHeight;
          canvas.height = videoElement.videoWidth;
        } else {
          canvas.width = videoElement.videoWidth;
          canvas.height = videoElement.videoHeight;
        }

        ctx.save();
        ctx.translate(canvas.width / 2, canvas.height / 2);
        ctx.rotate((this.rotationDegree * Math.PI) / 180);
        ctx.drawImage(
          videoElement,
          -videoElement.videoWidth / 2,
          -videoElement.videoHeight / 2,
          videoElement.videoWidth,
          videoElement.videoHeight
        );
        ctx.restore();

        const link = document.createElement('a');
        link.download = `snapshot_${this.deviceId}_${new Date().toISOString().replace(/[:.]/g, '-')}.png`;
        link.href = canvas.toDataURL('image/png');
        link.click();

        this.$message.success('截图已保存');
      } catch (error) {
        console.error('截图失败:', error);
        this.$message.error('截图失败');
      }
    },
    rotateVideo() {
      this.rotationDegree = (this.rotationDegree + 90) % 360;
      const videoElement = this.$refs.videoElement;
      const container = videoElement?.parentElement;
      
      if (videoElement && container) {
        container.classList.remove('rotate-0', 'rotate-90', 'rotate-180', 'rotate-270');
        container.classList.add(`rotate-${this.rotationDegree}`);
        
        const videoWidth = videoElement.videoWidth || videoElement.clientWidth;
        const videoHeight = videoElement.videoHeight || videoElement.clientHeight;
        const containerRect = container.getBoundingClientRect();
        const containerWidth = containerRect.width;
        const containerHeight = containerRect.height;
        
        const videoRatio = videoWidth / videoHeight || 16/9;
        
        if (this.rotationDegree === 90 || this.rotationDegree === 270) {
          videoElement.style.position = 'absolute';
          videoElement.style.top = '50%';
          videoElement.style.left = '50%';
          videoElement.style.transformOrigin = 'center center';
          
          const availableWidth = containerHeight;
          const availableHeight = containerWidth;
          const rotatedRatio = 1 / videoRatio;
          
          if (availableWidth / availableHeight > rotatedRatio) {
            const width = availableHeight * rotatedRatio;
            videoElement.style.width = `${width}px`;
            videoElement.style.height = `${availableHeight}px`;
          } else {
            const height = availableWidth / rotatedRatio;
            videoElement.style.width = `${availableWidth}px`;
            videoElement.style.height = `${height}px`;
          }
          
          const rotateValue = this.rotationDegree === 90 ? 90 : 270;
          videoElement.style.transform = `translate(-50%, -50%) rotate(${rotateValue}deg)`;
          
        } else {
          videoElement.style.position = 'absolute';
          videoElement.style.top = '50%';
          videoElement.style.left = '50%';
          videoElement.style.transformOrigin = 'center center';
          
          if (containerWidth / containerHeight > videoRatio) {
            const width = containerHeight * videoRatio;
            videoElement.style.width = `${width}px`;
            videoElement.style.height = '100%';
          } else {
            const height = containerWidth / videoRatio;
            videoElement.style.width = '100%';
            videoElement.style.height = `${height}px`;
          }
          
          const rotateValue = this.rotationDegree === 0 ? 0 : 180;
          videoElement.style.transform = `translate(-50%, -50%) rotate(${rotateValue}deg)`;
        }
        
        videoElement.style.maxWidth = 'none';
        videoElement.style.maxHeight = 'none';
      }
    },
    async startTalk() {
      if (this.isTalking) {
        this.stopTalk();
        return;
      }

      try {
        const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
        this.isTalking = true;
        this.$message.success('开始对讲');
      } catch (error) {
        console.error('获取麦克风失败:', error);
        this.$message.error('无法访问麦克风');
      }
    },
    stopTalk() {
      this.isTalking = false;
      this.$message.info('结束对讲');
    },
    clearRecordingTimer() {
      if (this.recordingTimer) {
        clearInterval(this.recordingTimer);
        this.recordingTimer = null;
      }
    },
    handleVideoMetadata() {
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        this.deviceInfo.resolution = `${videoElement.videoWidth}x${videoElement.videoHeight}`;
        
        if (this.rotationDegree !== 0) {
          this.rotateVideo();
        }
      }
    },
    handleResize() {
      if (this.resizeTimer) {
        clearTimeout(this.resizeTimer);
      }
      
      this.resizeTimer = setTimeout(() => {
        if (this.rotationDegree !== 0) {
          this.rotateVideo();
        }
      }, 200);
    },
    setMuted(muted) {
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        videoElement.muted = muted;
        this.isMuted = muted;
        
        if (muted) {
          this.preMuteVolume = this.volume;
          this.volume = 0;
        } else {
          this.volume = this.preMuteVolume || 50;
        }
        
        videoElement.volume = muted ? 0 : this.volume / 100;
      }
    }
  }
}
</script>

<style scoped>
.m3u8-player-container {
  width: 100%;
  height: 100%;
  background-color: #000;
  position: relative;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  border-radius: 8px;
}

.video-player {
  width: 100%;
  height: 100%;
  position: relative;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}

.video-js {
  width: 100%;
  height: 100%;
  object-fit: contain;
  display: block;
  transition: transform 0.3s ease;
  position: absolute;
  background-color: #000;
  transform-origin: center center;
  margin: auto;
}

/* 视频播放器基础容器 */
.video-player {
  width: 100%;
  height: 100%;
  position: relative;
  overflow: hidden;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #000;
}

/* 视频元素基础样式 */
.video-js {
  position: absolute;
  width: 100%;
  height: 100%;
  object-fit: contain;
  transition: transform 0.3s ease;
  transform-origin: center center;
}

/* 旋转状态的基础样式 */
.video-player .video-js {
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

/* 90度旋转状态 */
.video-player.rotate-90 {
  height: 100%;
}

.video-player.rotate-90 .video-js {
  transform: translate(-50%, -50%) rotate(90deg);
  width: auto;
  height: 100%;
  max-width: none;
  max-height: none;
}

/* 180度旋转状态 */
.video-player.rotate-180 .video-js {
  transform: translate(-50%, -50%) rotate(180deg);
}

/* 270度旋转状态 */
.video-player.rotate-270 {
  height: 100%;
}

.video-player.rotate-270 .video-js {
  transform: translate(-50%, -50%) rotate(270deg);
  width: auto;
  height: 100%;
  max-width: none;
  max-height: none;
}

/* 确保视频在所有状态下保持居中 */
.video-player::before {
  content: '';
  display: block;
  padding-top: 56.25%; /* 16:9 比例 */
}

/* 移除旋转状态下的padding */
.video-player.rotate-90::before,
.video-player.rotate-270::before {
  display: none;
}

.controls {
  padding: 12px 20px;
  display: flex;
  gap: 12px;
  justify-content: flex-end;
  width: 100%;
  z-index: 1000;
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  /* background: linear-gradient(to top, rgba(0, 0, 0, 0.8) 0%, rgba(0, 0, 0, 0.6) 50%, rgba(0, 0, 0, 0) 100%); */
  transition: opacity 0.3s ease;
  opacity: 0;
}

.m3u8-player-container:hover .controls {
  opacity: 1;
  transform: translateY(0);
}

.control-btn {
  padding: 8px !important;
  border: none !important;
  background-color: rgba(255, 255, 255, 0) !important;
  margin: 0 4px !important;
  /* box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2); */
  transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1);
  border-radius: 50% !important;
  width: 40px !important;
  height: 40px !important;
  display: flex !important;
  align-items: center !important;
  justify-content: center !important;
  backdrop-filter: blur(4px);
  -webkit-backdrop-filter: blur(4px);
}

/* 全屏模式样式 */
.flv-player-container:fullscreen,
.flv-player-container:-webkit-full-screen,
.flv-player-container:-moz-full-screen {
  background: #000;
  width: 100vw;
  height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
}

.flv-player-container:fullscreen .video-js,
.flv-player-container:-webkit-full-screen .video-js,
.flv-player-container:-moz-full-screen .video-js {
  max-height: 100vh;
  max-width: 100vw;
  margin: auto;
}

.flv-player-container:fullscreen .controls,
.flv-player-container:-webkit-full-screen .controls,
.flv-player-container:-moz-full-screen .controls {
  padding-bottom: max(env(safe-area-inset-bottom, 20px), 30px);
  opacity: 0;
  transition: opacity 0.3s ease;
}

.flv-player-container:fullscreen:hover .controls,
.flv-player-container:-webkit-full-screen:hover .controls,
.flv-player-container:-moz-full-screen:hover .controls {
  opacity: 1;
}

.control-btn:hover {
  background-color: rgba(255, 255, 255, 0.25) !important;
  transform: translateY(-2px) scale(1.05);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.4);
}

.control-btn:active {
  background-color: rgba(255, 255, 255, 0.3) !important;
  transform: translateY(0) scale(0.98);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.3);
}

.control-btn i {
  color: #fff;
  font-size: 18px;
  text-shadow: 0 1px 3px rgba(0, 0, 0, 0.3);
  transition: all 0.2s ease;
}

.control-btn:hover i {
  transform: scale(1.1);
}

/* 控制栏渐变背景 */
.controls::before {
  content: '';
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 120px;
  /* background: linear-gradient(to top, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0) 100%); */
  pointer-events: none;
  z-index: -1;
}

/* 全屏时的控制栏位置调整 */
:fullscreen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

:-webkit-full-screen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

:-moz-full-screen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

.error-message {
  color: #f56c6c;
  padding: 20px;
  text-align: center;
  background-color: rgba(0, 0, 0, 0.8);
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  border-radius: 6px;
  min-width: 200px;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 16px;
}

.refresh-button {
  background-color: #409eff;
  color: white;
  border: none;
  padding: 8px 16px;
  border-radius: 4px;
  cursor: pointer;
  display: flex;
  align-items: center;
  gap: 8px;
  transition: all 0.3s ease;
}

.refresh-button:hover {
  background-color: #66b1ff;
  transform: scale(1.05);
}

.refresh-button:active {
  transform: scale(0.95);
}

.refresh-button i {
  font-size: 16px;
}

.loading-message {
  color: white;
  padding: 16px 24px;
  text-align: center;
  background-color: rgba(0, 0, 0, 0.7);
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  border-radius: 6px;
  backdrop-filter: blur(4px);
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.2);
  animation: pulse 1.5s infinite;
}

/* 设备信息对话框样式 */
:deep(.device-info-dialog) {
  border-radius: 8px;
  overflow: hidden;
  background-color: rgba(0, 0, 0, 0.8) !important;
  width: 360px !important;
  transition: all 0.3s ease-in-out;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.3) !important;
}

:deep(.device-info-dialog.el-dialog__wrapper) {
  backdrop-filter: blur(5px);
}

:deep(.device-info-dialog .el-dialog) {
  transform-origin: center;
  animation: dialogFadeIn 0.3s;
}

@keyframes dialogFadeIn {
  from {
    opacity: 0;
    transform: scale(0.95);
  }
  to {
    opacity: 1;
    transform: scale(1);
  }
}

:deep(.device-info-dialog .el-dialog__header) {
  background-color: transparent !important;
  padding: 15px !important;
  border-bottom: 1px solid rgba(255, 255, 255, 0.1) !important;
}
:deep(.device-info-dialog .el-dialog__title) {
  color: white !important;
  font-size: 24px !important;
}
:deep(.el-dialog__body) {
  padding: 8px;
  font-size: 24px !important;
}

:deep(.device-info-dialog .el-dialog__headerbtn .el-dialog__close) {
  color: white !important;
  position: absolute;
  top: -10px;
  right: -10px;
}

.device-info {
  padding: 15px;
}

.device-info p {
  margin: 8px 0;
  line-height: 1.5;
  display: flex;
  justify-content: space-between;
  padding-bottom: 8px;
  color: white;
}

.device-info p:last-child {
  border-bottom: none;
}

.device-info strong {
  color: rgba(255, 255, 255, 0.7);
  margin-right: 12px;
  width: 140px;
}

/* 喊话按钮激活状态 */
.control-btn.el-button--primary {
  background-color: #409eff !important;
}

.control-btn.el-button--primary i {
  color: #fff;
}

@keyframes pulse {
  0% {
    opacity: 0.7;
  }
  50% {
    opacity: 1;
  }
  100% {
    opacity: 0.7;
  }
}
.record-controls {
  position: absolute;
  left: 20px;
  top: 30px;
  z-index: 10;
}

/* 录像状态指示器 */
.record-status {
  /* position: absolute;
  top: 20px;
  left: 20px; */
  display: flex;
  align-items: center;
  gap: 8px;
  color: #fff;
  font-size: 16px;
  background: rgba(0, 0, 0, 0.5);
  padding: 6px 12px;
  border-radius: 4px;
  z-index: 100;
}

.record-indicator {
  width: 12px;
  height: 12px;
  background-color: #f14d4d;
  border-radius: 50%;
  animation: pulse 1.5s infinite;
}

/* 音量控制样式 */
.volume-control {
  position: relative;
  display: inline-block;
}

.volume-slider-container {
  position: absolute;
  bottom: 40px;
  left: 50%;
  transform: translateX(-50%);
  background-color: rgba(0, 0, 0, 0.7);
  border-radius: 8px;
  padding: -20px 10px;
  z-index: 1001;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.3);
  transition: opacity 0.3s ease, transform 0.3s ease;
  height: 200px;
  display: flex;
  align-items: center;
  justify-content: center;
  opacity: 0;
  transform: translateX(-50%) translateY(10px);
  pointer-events: none;
}

.volume-control:hover .volume-slider-container {
  opacity: 1;
  transform: translateX(-50%) translateY(0);
  pointer-events: auto;
}

/* 自定义Element UI滑块样式 */
.volume-slider-container :deep(.el-slider__runway) {
  background-color: rgba(255, 255, 255, 0.2);
  width: 4px;
}

.volume-slider-container :deep(.el-slider__bar) {
  background-color: #409eff;
  width: 4px;
}

.volume-slider-container :deep(.el-slider__button) {
  width: 12px;
  height: 12px;
  border: 2px solid #409eff;
  background-color: white;
  transition: transform 0.2s ease;
}

.volume-slider-container :deep(.el-slider__button):hover {
  transform: scale(1.2);
}

.volume-slider-container :deep(.el-slider__button-wrapper) {
  width: 24px;
  left: -10px;
}
/* 视频旋转时的容器样式 */
.video-container {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
}

/* 适配不同旋转角度的视频尺寸 */
.video-js[style*="rotate(90deg)"],
.video-js[style*="rotate(270deg)"] {
  width: auto !important;
  height: 100% !important;
  max-height: -webkit-fill-available !important;
}
</style>